pub struct FrameSet { /* private fields */ }Expand description
A pool of reusable framebuffer image IDs allocated for a buffer collection.
Implementations
Sourceimpl FrameSet
impl FrameSet
pub fn new(available: BTreeSet<ImageId>) -> FrameSet
Sourcepub fn take_image(&mut self) -> Option<ImageId>
pub fn take_image(&mut self) -> Option<ImageId>
Removes and returns the first available image ID, or None if empty.
Sourcepub fn return_image(&mut self, image_id: ImageId)
pub fn return_image(&mut self, image_id: ImageId)
Inserts the returned image ID back into self.available.
image_id must be one of the IDs previously returned by take_image.
Sourcepub fn no_images_in_use(&self) -> bool
pub fn no_images_in_use(&self) -> bool
Returns true if all images allocated for this pool are available.
Sourcepub fn image_count_for_testing(&self) -> usize
pub fn image_count_for_testing(&self) -> usize
Returns the total number of images in the pool.
Sourcepub fn available_count_for_testing(&self) -> usize
pub fn available_count_for_testing(&self) -> usize
Returns the number of currently available images in the pool.